{ config, lib, pkgs, user, ...}:

{
  home = {
    username = "${user}";
    homeDirectory = "/home/${user}";

    packages = with pkgs; [
      bat
      firefox
      htop
    ];

    stateVersion = "22.05";
  };

  programs = {
    alacritty = {
      enable = true;
      settings = {
        font = {
          normal.family = "DejaVu Sans Mono";
	  size = 8;
	};
	colors = {
	  primary = {
            background = "#002b36";
            foreground = "#839496";
          };
	  cursor = {
            text = "#002b36";
	    cursor = "#839496";
          };
	  normal = {
	    black = "#073642";
	    red = "#dc322f";
	    green = "#859900";
	    yellow = "#b58900";
	    blue = "#268bd2";
	    magenta = "#d33682";
	    cyan = "#2aa198";
	    white = "#eee8d5";
          };
	  bright = {
	    black = "#002b36";
	    red = "#cb4b16";
	    green = "#586e75";
	    yellow = "#657b83";
	    blue = "#839496";
	    magenta = "#6c71c4";
	    cyan = "#93a1a1";
	    white = "#fdf6e3";
          };
	};
    git = {
      enable = true;
      userName = "Michael Mandl";
      userEmail = "mandlm@molez.net";
      extraConfig = {
	core.editor = "nvim";
	fetch.writeCommitGraph = true;
	format.pretty = "format:%C(yellow)%h %Cblue%>(12)%ad %C(red)%G? %Cgreen%<(7,trunc)%aN%Cred%d %Creset%s";
        init.defaultBranch = "main";
	log.date = "relative";
	pull.rebase = true;
	rebase.autostash = true;
	rerere.enabled = true;
	worktree.guessRemote = true;
      };
    };

      };
    };

    tmux = {
      enable = true;
      newSession = true;
      extraConfig = ''
        set-option -g status off
      '';
    };

    zsh = {
      enable = true;
      enableSyntaxHighlighting = true;
      history.size = 10000;

      oh-my-zsh = {
        enable = true;
	plugins = [ "git" "tmux" "vi-mode" ];
	theme = "intheloop";
      };
    };

    home-manager.enable = true;
  };
}
